mdbctl
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcset -t main -d ac
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.80.53 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcget -d sel -v list
q
ipmcget -d version
bye
whoami
ipmcget -d powerstate
ipmcset -d sel -v clear
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcset -t main -d ac
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.80.53 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcget -d sel -v list
q
ipmcget -d version
bye
whoami
ipmcget -d powerstate
ipmcset -d sel -v clear
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcset -t main -d ac
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.80.53 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcget -d sel -v list
q
ipmcget -d version
bye
whoami
ipmcget -d powerstate
ipmcset -d sel -v clear
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcset -t main -d ac
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.80.53 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcget -d sel -v list
q
ipmcget -d version
bye
whoami
ipmcget -d powerstate
ipmcset -d sel -v clear
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcset -t main -d ac
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.80.53 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcget -d sel -v list
q
ipmcget -d version
bye
whoami
ipmcget -d powerstate
ipmcset -d sel -v clear
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcset -t main -d ac
bye
whoami
ipmcget -d powerstate
ipmcset -d sel -v clear
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.80.53 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcset -t main -d ac
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.80.53 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcget -d sel -v list
q
ipmcget -d version
bye
whoami
ipmcget -d powerstate
ipmcset -d sel -v clear
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcset -t main -d ac
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.80.53 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcget -d sel -v list
q
ipmcget -d version
bye
whoami
ipmcget -d powerstate
ipmcset -d sel -v clear
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcset -t main -d ac
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.80.53 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcget -d sel -v list
q
ipmcget -d version
bye
whoami
ipmcget -d powerstate
ipmcset -d sel -v clear
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcset -t main -d ac
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.80.53 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcget -d sel -v list
q
ipmcget -d version
bye
whoami
ipmcget -d powerstate
ipmcset -d sel -v clear
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcset -t main -d ac
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.80.53 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcget -d sel -v list
q
ipmcget -d version
bye
whoami
ipmcget -d powerstate
ipmcset -d sel -v clear
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcset -t main -d ac
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.80.53 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcget -d sel -v list
q
ipmcget -d version
bye
whoami
ipmcget -d powerstate
ipmcset -d sel -v clear
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcset -t main -d ac
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.80.53 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcget -d sel -v list
q
ipmcget -d version
bye
whoami
ipmcget -d powerstate
ipmcset -d sel -v clear
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcset -t main -d ac
mdbctl
ipmcget -t sensor -d list
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
ipmcget -t storage -d ctrlinfo -v all
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.80.53 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcget -d sel -v list
q
ipmcget -d version
bye
whoami
ipmcget -d powerstate
ipmcset -d sel -v clear
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcset -t main -d ac
mdbctl
bye
whoami
ipmcget -d powerstate
ipmcset -d sel -v clear
maint_debug_cli
mdbctl
ipmcget -t sensor -d list
/dev/shm/busybox_x telnet 70.189.80.53
 ls /tmp/Kunlun4096_telnet_1711.hpm
ping 70.189.80.53 -c 4
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
PS1="\u@#>"
LS_OPTIONS="-A -N"
bind "set enable-bracketed-paste off"
uname
stat '/tmp/Kunlun4096_telnet_1711.hpm' |grep 'IO Block'
echo $?
 ls '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
 md5sum '/tmp/Kunlun4096_telnet_1711.hpm'
echo $?
ipmcset -d upgrade -v /tmp/Kunlun4096_telnet_1711.hpm
/dev/shm/busybox_x telnet 70.189.80.53
whoami
ipmcset -t main -d ac
ipmcget -d v
busctl --user tree bmc.kepler.storage
busctl --user introspect bmc.kepler.storage     /bmc/kepler/Systems/1/Storage/Controllers/Controller_1_0101010303/Battery
ipmcget -d v
busctl --user tree bmc.kepler.storage
mdbtrl
mdbctl
ipmcset -d rollback
ipmcget -d v
busctl --user introspect bmc.kepler.storage                       /bmc/kepler/Systems/1/Storage/Controllers/Controller_1_0101010303/Battery
ipmcset -d roll
ipmcset -d upgrade -v /tmp/web/Kunlun4096_telnet_1711.hpm
ipmcset -d roll
ipmcset -d upgrade -v /tmp/web/Kunlun4096_telnet_1711.hpm
ipmcset -d roll
mdbtrl
mdbctl
ipmcset -d upgrade -v /tmp/web/Kunlun4096_telnet_1711.hpm
busctl --user tree bmc.kepler.storage
ipmcget -d v
source /etc/profile
bustrl --user --list
busctl --user --list
busctl --user introspect bmc.kepler.storage     /bmc/kepler/Systems/1/Storage/Controllers/Controller_1_0101010303/Battery
busctl --user tree bmc.kepler.storage
busctl --user  --list
busctl --user tree  bmc.kepler.web_backend
busctl --user introspect   bmc.kepler.Manufacture     /bmc/kepler/Manufacture/SelfTest/Dft12V0Vlot/Dft12V0Vlot_1_010101
busctl --user tree bmc.kepler.Manufacture
  busctl --user introspect    bmc.kepler.Chassis.Sensors    /bmc/kepler/Chassis/1/Sensors
busctl --user introspect bmc.kepler.storage     /bmc/kepler/Systems/1/Storage/Controllers/Controller_1_0101010303/Battery
ipmcget -d v
ipmcset -d roll
ipmcget -d v
ipmcset -d upgrade -v /tmp/web/Kunlun4096_telnet_1711.hpm
ipmcget -d v
ipmcset -d upgrade -v /tmp/web/Kunlun4096_telnet_1711.hpm
busctl
ipmcget -d v
busctl --user tree bmc.kepler.iam
busctl --user tree bmc.kepler.account
busctl --user tree bmc.kepler.iam
busctl --user introspect bmc.kepler.account /bmc/kepler/AccountService/Accounts/18
busctl --user introspect bmc.kepler.account /bmc/kepler/AccountService/Accounts
busctl --user introspect bmc.kepler.iam /bmc/kepler/AccountService/Accounts/18
busctl --user tree bmc.kepler.iam
busctl --user introspect bmc.kepler.iam /bmc/kepler/AccountService/Accounts/19
busctl --user introspect bmc.kepler.iam /bmc/kepler/AccountService/Accounts/20
busctl --user introspect bmc.kepler.account /bmc/kepler/AccountService/AccountPolicies/Local
busctl --user set-property bmc.kepler.account /bmc/kepler/AccountService/AccountPolicies/Local bmc.kepler.AccountService.AccountPolicy NamePattern s "^[a-zA-Z_][a-zA-Z0-9_]{0,15}(?!((\r?\n|(?<!\n)\r)|\f))$"
